"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateDestinationQuestion = validateDestinationQuestion;
exports.validateMtaPath = validateMtaPath;
exports.validateMtaId = validateMtaId;
exports.validateAbapService = validateAbapService;
const i18n_1 = require("../i18n");
const fs_1 = require("fs");
const path_1 = require("path");
/**
 *
 * @param input The input string to check for emptiness.
 * @returns returns true if the input string is not empty, otherwise false.
 */
function isNotEmpty(input) {
    return !!input?.trim();
}
/**
 * Validates the input string for the following:
 * - It must not be empty after trimming whitespace.
 * - It must contain only alphanumeric characters, underscores, or dashes.
 * - It must not exceed 200 characters.
 *
 * @param {string} input - The input string to validate.
 * @returns {boolean|string} `true` if the input is valid, otherwise an error message.
 */
function validateInput(input) {
    if (!isNotEmpty(input)) {
        return (0, i18n_1.t)('errors.emptyDestinationNameError');
    }
    const result = /^[a-z0-9_-]+$/i.test(input);
    if (!result) {
        return (0, i18n_1.t)('errors.destinationNameError');
    }
    if (input.length > 200) {
        return (0, i18n_1.t)('errors.destinationNameLengthError');
    }
    return true;
}
/**
 * Validates the destination name or input string. If `allowEmptyChoice` is true,
 * the validation will pass immediately. Otherwise, the input will be validated
 * against rules (non-empty, valid characters, length check).
 *
 * @param {string} input - The destination name or input string to validate.
 * @param {boolean} allowEmptyChoice - Whether to allow an empty input as a valid choice.
 * @returns {boolean|string} `true` if the input is valid or empty choices are allowed, otherwise an error message.
 */
function validateDestinationQuestion(input, allowEmptyChoice = false) {
    if (allowEmptyChoice) {
        return true;
    }
    return typeof input === 'string' ? validateInput(input) : true;
}
/**
 * Validates the provided MTA path.
 *
 * @param {string} input - The input string representing the MTA path to validate.
 * @returns {boolean|string} - Returns `true` if the path is valid, or an error message if the path is invalid or does not exist.
 */
function validateMtaPath(input) {
    const filePath = input?.trim();
    return (filePath && (0, fs_1.existsSync)(filePath)) || (0, i18n_1.t)('errors.folderDoesNotExistError', { filePath: filePath });
}
/**
 * Validates the provided MTA ID.
 *
 * This function performs the following checks:
 * - Ensures the input is a non-empty string.
 * - Validates the input against a regex pattern.
 * - Checks if the MTA ID already exists in the specified path.
 *
 * @param {string} input - The MTA ID to validate.
 * @param {CfAppRouterDeployConfigAnswers} previousAnswers - The previous answers, containing the MTA path.
 * @returns {boolean|string} - Returns true if the MTA ID is valid, or an error message if validation fails.
 */
function validateMtaId(input, previousAnswers) {
    if (typeof input !== 'string' || !input.trim()) {
        return (0, i18n_1.t)('errors.noMtaIdError');
    }
    if (input.length > 100) {
        return (0, i18n_1.t)('errors.invalidMtaIdError');
    }
    const idPattern = /^[a-zA-Z_]+[a-zA-Z0-9_\-.]*$/;
    if (!idPattern.exec(input)) {
        return (0, i18n_1.t)('errors.invalidMtaIdError');
    }
    if ((0, fs_1.existsSync)((0, path_1.join)(previousAnswers.mtaPath, input.trim()))) {
        return (0, i18n_1.t)('errors.mtaIdAlreadyExistError', { mtaPath: previousAnswers.mtaPath });
    }
    // All checks passed
    return true;
}
/**
 * Validates the ABAP service choice and provides error handling.
 *
 * @param {string} choice - The selected choice for the ABAP service.
 * @param {ErrorHandler} errorHandler - An instance of an error handler.
 * @returns {string | boolean} - Returns `true` if the choice is valid.
 */
function validateAbapService(choice, errorHandler) {
    if (!choice) {
        const userMsg = errorHandler.getErrorMsg('', true);
        const checkConsoleMsg = (0, i18n_1.t)('errors.errorScpAbapSourceDiscoveryCheckLog');
        return userMsg ? `${userMsg} ${checkConsoleMsg}` : false;
    }
    return true;
}
//# sourceMappingURL=validators.js.map